@@ -1,5 +1,5 @@
 from .newmetric import *
-class NewMetricChild(NewMetric): # discuss the case when more than 1 new metric is defined, new class to be created or design to be in dict form
+class PerfNewMetricChild(NewMetric): # discuss the case when more than 1 new metric is defined, new class to be created or design to be in dict form
     """
     Base class to add new metrics to the Veritas library.
 
@@ -25,8 +25,8 @@ class NewMetricChild(NewMetric): # discuss the case when more than 1 new metric
 
     metric_type = "perf"
     metric_group = "classification"
-    metric_name = "custom_new_metric"
-    metric_definition = "custom_new_metric child"
+    metric_name = "perf_new_metric"
+    metric_definition = "perf_new_metric child"
     metric_parity_ratio = "parity"
     enable_flag = True
 
@@ -50,4 +50,4 @@ class NewMetricChild(NewMetric): # discuss the case when more than 1 new metric
         return (metric_value)    #check names later
     
     
-#check enable flag i fariness metric and performance metrics    
\ No newline at end of file
+#check enable flag i fariness metric and performance metrics    
