@@ -1,11 +1,11 @@
 #import ModelWrapper
 from .custom.modelwrapper import ModelWrapper
-from veritas.utility import check_datatype, check_value, check_label
+from .utility import check_datatype, check_value, check_label
 import numpy as np
 import pandas as pd
-from veritas.fairness.fairness import Fairness
-from veritas.fairness.credit_scoring import CreditScoring
-from veritas.fairness.customer_marketing import CustomerMarketing
+from .fairness.fairness import Fairness
+from .fairness.credit_scoring import CreditScoring
+from .fairness.customer_marketing import CustomerMarketing
 from .ErrorCatcher import VeritasError
 import sys
 
